@@ -1,7 +1,6 @@
-import re
 from functools import reduce
 
-from sympy import Mul, preorder_traversal, symbols, Function, simplify, Add, Basic, Symbol
+from sympy import Mul, preorder_traversal, symbols, Function, simplify, Add, Basic, Symbol, sympify
 
 # 预定义前缀，算子用前缀进行区分更方便。
 # 当然也可以用是否在某容器中进行分类
@@ -44,35 +43,11 @@ def register_symbols(syms, globals_, is_function: bool):
     return globals_
 
 
-def dict_to_exprs(exprs_src, globals_, safe: bool = True):
-    exprs_src = {k: safe_eval(v, globals_, k, safe) for k, v in exprs_src.items()}
+def dict_to_exprs(exprs_src, globals_):
+    exprs_src = {k: sympify(v, globals_, evaluate=False) for k, v in exprs_src.items()}
     return exprs_src
 
 
-def safe_eval(string, globals_, k=None, safe: bool = True):
-    # print(string)
-    code = compile(string, '<user input>', 'eval')
-    if safe:
-        reason = None
-        banned = ('eval', 'compile', 'exec', 'getattr', 'hasattr', 'setattr', 'delattr',
-                  'classmethod', 'globals', 'help', 'input', 'isinstance', 'issubclass', 'locals',
-                  'open', 'print', 'property', 'staticmethod', 'vars')
-        for name in code.co_names:
-            if re.search(r'^__\S*__$', name):
-                reason = 'attributes not allowed'
-            elif name in banned:
-                reason = 'code execution not allowed'
-            if reason:
-                raise NameError(f'{name} not allowed : {reason}')
-
-    try:
-        return eval(code, globals_)
-    except:
-        print(k)
-        print(string)
-        raise
-
-
 def append_node(node, output_exprs):
     """添加到队列。其中，-x将转为x
 
@@ -361,7 +336,7 @@ def _replace__repeat(e):
         node_name = get_node_name(node)
         node_args0_name = get_node_name(node.args[0])
         if node_name == node_args0_name:
-            if node.name in ('cs_rank', 'sign', 'Abs', 'abs_'):
+            if node_name in ('cs_rank', 'sign', 'Abs', 'abs_'):
                 replacements.append((node, node.args[0]))
     for node, replacement in replacements:
         print(node, '  ->  ', replacement)
